@@ -30,9 +30,11 @@ test_error(daemons(url = local_url(), dispatcher = "t"), "should be either TRUE
 test_error(dispatcher(client = "URL"), "must be 1 or greater")
 test_error(daemon("URL"), "Invalid argument")
 test_error(launch_local(1L), "daemons must be set")
+test_true(!daemons_set())
 test_type("character", host_url())
-test_true(startsWith(host_url(tls = TRUE), "tls"))
-test_true(grepl("5555", host_url(port = 5555), fixed = TRUE))
+test_type("character", names(host_url()))
+test_true(all(startsWith(host_url(tls = TRUE), "tls")))
+test_true(all(grepl("5555", host_url(port = 5555), fixed = TRUE)))
 test_identical(local_url(tcp = TRUE), "tcp://127.0.0.1:0")
 test_true(grepl("5555", local_url(tcp = TRUE, port = 5555), fixed = TRUE))
 test_type("list", ssh_config("ssh://remotehost"))
@@ -42,6 +44,7 @@ test_print(r)
 test_true(is_mirai_error(r <- `class<-`("Error in: testing\n", c("miraiError", "errorValue", "try-error"))))
 test_print(r)
 test_null(r$stack.trace)
+test_true(!on_daemon())
 test_equal(mirai:::.DollarNames.miraiError(r, "c"), "class")
 test_true(mirai:::is.promising.mirai())
 test_true(mirai:::is.promising.mirai_map())
@@ -50,6 +53,9 @@ test_null(nextstream())
 test_null(nextget("pid"))
 for (i in 0:4)
   test_type("character", nextcode(i))
+test_null(register_serial("test_klass1", serialize, unserialize))
+test_null(register_serial(c("test_klass2", "test_klass3"), list(serialize, serialize), list(unserialize, unserialize)))
+test_equal(length(mirai:::.[["serial"]][[3L]]), 3L)
 # mirai and daemons tests
 connection && {
   Sys.sleep(1L)
@@ -68,9 +74,13 @@ connection && {
   if (!is_error_value(call_mirai_(m)$data)) test_equal(m$data, 8L)
   test_true(!stop_mirai(m))
   Sys.sleep(1L)
+  m <- mirai(mirai::on_daemon(), .timeout = 2000L)
+  if (!is_error_value(m[])) test_true(m[])
+  Sys.sleep(1L)
   test_equal(1L, d <- daemons(1L, dispatcher = FALSE, asyncdial = FALSE, seed = 1546L))
   test_print(d)
   test_error(daemons(1L), "daemons already set")
+  test_true(daemons_set())
   me <- mirai(mirai::mirai(), .timeout = 2000L)[]
   if (!is_mirai_error(me)) test_true(is_error_value(me))
   if (is_mirai_error(me)) test_type("list", me$stack.trace)
@@ -79,6 +89,8 @@ connection && {
   test_true(!is_mirai_interrupt(me))
   test_class("errorValue", me)
   test_print(me)
+  m <- mirai(mirai::on_daemon(), .timeout = 2000L)
+  if (!is_error_value(m[])) test_true(m[])
   df <- data.frame(a = 1, b = 2, .Random.seed = 0)
   dm <- mirai(as.matrix(df), .args = list(df = df), .timeout = 2000L)
   test_true(is_mirai(call_mirai(dm)))
@@ -305,6 +317,7 @@ connection && requireNamespace("promises", quietly = TRUE) && Sys.getenv("NOT_CR
 connection && Sys.getenv("NOT_CRAN") == "true" && {
   Sys.sleep(0.5)
   test_equal(daemons(1, cleanup = FALSE, maxtasks = 2L, id = 125L), 1L)
+  test_true(daemons_set())
   test_equal(mirai(1)[], mirai(1)[])
   m <- mirai(0L)
   Sys.sleep(1L)
